@@ -10,6 +10,8 @@
 #define QT_FEATURE_eglfs_egldevice -1
 #define QT_FEATURE_eglfs_gbm -1
 #define QT_FEATURE_eglfs_mali -1
+#define QT_FEATURE_eglfs_openwfd -1
+#define QT_FEATURE_eglfs_rcar -1
 #define QT_FEATURE_eglfs_viv -1
 #define QT_FEATURE_eglfs_viv_wl -1
 #define QT_FEATURE_evdev -1
